# Whip validator report

Date: 2018-08-22 21:32

## Summary

Total rows: 5

#### Unknown fields

These fields are described in the whip specifications, but are missing in the data:

nonExistingColumn

#### Unspecified fields

These fields exist in data, but have no whip specification:

accessRights associatedReferences class continent coordinateUncertaintyInMeters countryCode dataGeneralizations datasetName geodeticDatum georeferenceRemarks id identificationVerificationStatus informationWithheld institutionCode kingdom lifeStage municipality nomenclaturalCode order ownerInstitutionCode phylum rightsHolder samplingEffort samplingProtocol scientificName scientificNameAuthorship sex stateProvince taxonRank verbatimCoordinates verbatimCoordinateSystem verbatimEventDate verbatimLocality verbatimSRS vernacularName

#### General warnings

Following fields mentioned inside if specifications do not exist inside the document: 'anotherNonExistigColumn'

## Specifications

#### basisOfRecord

allowed
`HumanObservation, PreservedSpecimen, Occurrence`
4

# | Data value | Message | Failed rows | First row
--- | --- | --- | --- | ---
1 | `Human Observation` | unallowed value Human Observation | 1 | 3

empty
`False`
5

#### datasetID

allowed
`http://doi.org/10.15468/njgbmh`
5
empty
`False`
5

#### decimalLatitude

empty
`False`
5
max
`51.51`
4

# | Data value | Message | Failed rows | First row
--- | --- | --- | --- | ---
1 | `58.11234` | max value is 51.51 | 1 | 4

min
`50.68`
5
numberformat
`.5`
5

#### decimalLongitude

empty
`False`
5
max
`5.92`
4

# | Data value | Message | Failed rows | First row
--- | --- | --- | --- | ---
1 | `58.0` | max value is 5.92 | 1 | 4

min
`2.54`
5
numberformat
`.5`
4

# | Data value | Message | Failed rows | First row
--- | --- | --- | --- | ---
1 | `58.0` | numberformat of value '58.0' not in agreement with '.5' | 1 | 4

#### eventDate

dateformat
`%Y-%m-%d, %Y-%m, %Y`
3

# | Data value | Message | Failed rows | First row
--- | --- | --- | --- | ---
1 | `07241981` | string format of value '07241981' not compliant with '['%Y-%m-%d', '%Y-%m', '%Y']' | 1 | 2
2 | `1984-07-24/2000-01-03` | string format of value '1984-07-24/2000-01-03' not compliant with '['%Y-%m-%d', '%Y-%m', '%Y']' | 1 | 1

empty
`False`
5
maxdate
`2014-12-31`
4

# | Data value | Message | Failed rows | First row
--- | --- | --- | --- | ---
1 | `07241981` | value '07241981' could not be interpreted as date or datetime | 1 | 2

mindate
`1830-01-01`
4

# | Data value | Message | Failed rows | First row
--- | --- | --- | --- | ---
1 | `07241981` | value '07241981' could not be interpreted as date or datetime | 1 | 2

#### individualCount

empty
`False`
5
max
`200`
5
min
`1`
5
numberformat
`x`
5

#### language

allowed_if_1
`nl`
5
empty
`True`
5
empty_if_1
`False`
5

#### license

empty
`False`
5
stringformat
`url`
5

#### nonExistingColumn

allowed
`anything`
5
empty
`False`
5

#### occurrenceID

empty
`False`
4

# | Data value | Message | Failed rows | First row
--- | --- | --- | --- | ---
1 | `` | empty values not allowed | 1 | 5

#### recordedBy

delimitedvalues
``
4

# | Data value | Message | Failed rows | First row
--- | --- | --- | --- | ---
1 | `observerID:JNHRLPPPP | observerID:JNHRLPPPP` | duplicate values in delimitedvalues | 1 | 3

empty
`False`
5
maxlength
`25`
2

# | Data value | Message | Failed rows | First row
--- | --- | --- | --- | ---
1 | `observerID:JNHRLPAAA | observerID:JNHRLCTGH` | max length is 25 | 1 | 1
2 | `observerID:JNHRLPPPP | observerID:JNHRLPPPP` | max length is 25 | 1 | 3
3 | `observerID:JNHRLP ; observerID:JNHRLC` | max length is 25 | 1 | 2

maxlength_delimitedvalue
`17`
3

# | Data value | Message | Failed rows | First row
--- | --- | --- | --- | ---
1 | `observerID:JNHRLP ; observerID:JNHRLC` | max length is 17 | 1 | 2
2 | `observerID:JNHRLPAAA` | max length is 17 | 1 | 1
3 | `observerID:JNHRLCTGH` | max length is 17 | 1 | 1

regex_delimitedvalue
`observerID:.+`
5

#### type

allowed
`Event, PhysicalObject, Text`
4

# | Data value | Message | Failed rows | First row
--- | --- | --- | --- | ---
1 | `Evet` | unallowed value Evet | 1 | 4

allowed_if_1
`Event`
3

# | Data value | Message | Failed rows | First row
--- | --- | --- | --- | ---
1 | `PhysicalObject` | unallowed value PhysicalObject | 1 | 5
2 | `Evet` | unallowed value Evet | 1 | 4

allowed_if_2
`PhysicalObject`
5
allowed_if_3
`Text`
5
empty
`False`
5
empty_if_1
`False`
5
empty_if_2
`False`
5
empty_if_3
`False`
5
minlength_if_1
`10`
2

# | Data value | Message | Failed rows | First row
--- | --- | --- | --- | ---
1 | `Event` | min length is 10 | 2 | 1
2 | `Evet` | min length is 10 | 1 | 4